(analyze-changes {:keys [uri text version]}
{:keys [producer db*] :as components})(did-change-watched-files changes
{:keys [db* watched-files-chan] :as components})(force-get-document-text uri {:keys [db*] :as components})Get document text from db, if document not found, tries to open the document
Get document text from db, if document not found, tries to open the document
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |